#
# spec file for package gn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gn
Version:        0.20240730
Release:        2.2
Summary:        A meta-build system that generates build files for Ninja
License:        BSD-3-Clause
URL:            https://gn.googlesource.com/
Source0:        %{name}-%{version}.tar.xz
Patch0:         redundant-move.patch
Patch1:         subprocess-python36.patch
BuildRequires:  ninja
BuildRequires:  python3-base
ExcludeArch:    ppc
%if %{?suse_version} < 1550
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif

%description
GN is a meta-build system that generates build files for Ninja.

%prep
%setup -q
%if 0%{?suse_version} > 1550
%patch -P 0 -p1
%endif
if test $(readlink /usr/bin/python3) = "python3.6" ; then
%patch -P 1 -p1
fi

%build
ARCH_FLAGS="`echo %{optflags} | sed -e 's/-O2//g'`"
%ifarch %arm
ARCH_FLAGS="$ARCH_FLAGS -Wno-unused-value"
%endif
%if 0%{?suse_version} < 1550
export CXX=g++-13
%else
export CXX=g++
%endif
export AR=ar
export CXXFLAGS="${ARCH_FLAGS}"
# bootstrap
python3 build/gen.py \
  --no-strip \
  --no-last-commit-position \
  --no-static-libstdc++
PV=%{version}
cat >out/last_commit_position.h <<-EOF
	#ifndef OUT_LAST_COMMIT_POSITION_H_
	#define OUT_LAST_COMMIT_POSITION_H_
	#define LAST_COMMIT_POSITION_NUM ${PV##0.}
	#define LAST_COMMIT_POSITION "${PV}"
	#endif  // OUT_LAST_COMMIT_POSITION_H_
EOF
%ninja_build -C out gn

%check
%ninja_build -C out gn_unittests
./out/gn_unittests

%install
install -Dm 0755 out/%{name} %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Sep 24 2024 ro@suse.de
- add "-Wno-unused-value" to fix build on armv6/armv7
* Fri Aug  2 2024 ro@suse.com
- Update to version 0.20240730:
  * Rust: link_output, depend_output and runtime_outputs for dylibs
  * Add missing reference section to function_toolchain.cc
  * Do not cleanup args.gn imports located in the output directory.
  * Fix expectations in NinjaRustBinaryTargetWriterTest.SwiftModule
  * Do not add native dependencies to the library search path
  * Support linking frameworks and swiftmodules in Rust targets
  * [desc] Silence print() statements when outputing json
  * infra: Move CI/try builds to Ubuntu-22.04
  * [MinGW] Fix mingw building issues
  * [gn] Fix "link" in the //examples/simple_build/build/toolchain/BUILD.gn
  * [template] Fix "rule alink_thin" in the //build/build_linux.ninja.template
  * Allow multiple --ide switches
  * [src] Add "#include <limits>" in the //src/base/files/file_enumerator_win.cc
  * Get updates to infra/recipes.py from upstream
  * Revert "Teach gn to handle systems with > 64 processors"
  * [apple] Rename the code-signing properties of create_bundle
  * Fix a typo in "gn help refs" output
  * Revert "[bundle] Use "phony" builtin tool for create_bundle targets"
  * [bundle] Use "phony" builtin tool for create_bundle targets
  * [ios] Simplify handling of assets catalog
  * [swift] List all outputs as deps of "source_set" stamp file
  * [swift] Update `gn check ...` to consider the generated header
  * [swift] Set `restat = 1` to swift build rules
  * Fix build with gcc12
  * [label_matches] Add new functions label_matches(), filter_labels_include() and filter_labels_exclude()
  * [swift] Remove problematic use of "stamp" tool
  * Implement new --ninja-outputs-file option.
  * Add NinjaOutputsWriter class
  * Move InvokePython() function to its own source file.
  * zos: build with -DZOSLIB_OVERRIDE_CLIB to override creat
  * Enable C++ runtime assertions in debug mode.
  * Fix regression in MakeRelativePath()
  * fix: Fix Windows MakeRelativePath.
  * Add long path support for windows
  * Ensure read_file() files are considered by "gn analyze"
  * apply 2to3 to for some Python scripts
  * Add rustflags to desc and help output
  * strings: support case insensitive check only in StartsWith/EndsWith
  * add .git-blame-ignore-revs
  * use std::{string,string_view}::{starts_with,ends_with}
  * apply clang-format to all C++ sources
  * add forward declaration in rust_values.h
  * Add `root_patterns` list to build configuration.
  * Use c++20 in GN build
  * update windows sdk to 2024-01-11
  * update windows sdk
  * Add linux-riscv64.
  * Update OWNERS list.
  * remove unused function
  * Ignore build warning -Werror=redundant-move
  * Fix --as=buildfile `gn desc deps` output.
  * Update recipe engine to 9dea1246.
  * treewide: Fix spelling mistakes
- add subprocess-python36.patch
  to build with python3.6 on sle15
- use gcc-13 instead of gcc-12
  to work around maybe uninitialized error
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Nov 10 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.20231023:
  * many updates to support Chromium 119 build
- drop deprecated_copy.patch
- add redundant-move.patch
* Thu Mar  9 2023 Callum Farmer <gmbr3@opensuse.org>
- Bump Leap's GCC version to 12 to align with the other Chromium
  tools
- Exclude ppc - it doesn't build
* Sun Dec  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Add deprecated_copy.patch: fix deprecated copy GCC warnings
- Go back to GCC
- Use newer libs and GCC on Leap 15.3 & 15.4
* Fri Sep 10 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix build with riscv64
* Wed Sep  1 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 0.20210811:
  * C++ modernization improvements.
  * Minor style updates.
  * Enable GN to build & run on z/OS
  * Fix a typo in the doc of "generated_file"
  * Update doc/help to say --ninja-executable works for VS Flags
  * [rust] Fix and test dylib support
  * Add 'rustenv' to 'gn desc' output
  * [rust] Clean up logic in PullDependentTargetLibsFrom
  * Link Rust binaries against transitive public_deps
  * Fix linking dynamic libraries in Rust binaries
- Remove patches:
  * gn-flags.patch
  * gn-always-python3.patch
  * riscv.patch
* Sat Oct 31 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add riscv.patch to add support for RISCV
* Sat Oct 10 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 0.1807:
  * no upstream changelog
* Thu Apr  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1726:
  * no upstream changelog
- Rebase patches:
  * gn-always-python3.patch
  * gn-flags.patch
* Wed Oct 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1616:
  * no upstream changelog
- Remove merged patch gn-add_missing_arm_files.patch
- Add patch to always use python3 in tests:
  * gn-always-python3.patch
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1544:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Fri Nov  9 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to add missing files to fix armv7 build:
  * gn-add_missing_arm_files.patch
* Tue Oct 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.1479:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Tue Aug 28 2018 tchvatal@suse.com
- Update to 0.1463:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Mon Aug  6 2018 tchvatal@suse.com
- Fix building on openSUSE Leap 42.3
* Wed Jul 25 2018 tchvatal@suse.com
- Initial commit, package used to generate ninja files, used
  when configuring chromium
